from .llm_storage_routes import llm_bp
from .chat_routes import chat_bp
from .search_routes import search_bp
from .upload_routes import upload_bp
from .worker_routes import worker_bp
from .v1_routes import v1_bp
from .prompt_routes import prompt_bp
from .ml_routes import ml_bp
from .phone_brick_routes import phone_brick_bp
from .discord_routes import discord_bp
from .auth_proxy_routes import auth_proxy_bp
from .welcome_routes import welcome_bp
from .comms_routes import comms_bp
